Index: src/compilation-cache.h |
=================================================================== |
--- src/compilation-cache.h (revision 1344) |
+++ src/compilation-cache.h (working copy) |
@@ -55,10 +55,11 @@ |
int line_offset, |
int column_offset); |
// Finds the function boilerplate for a source string for |
// eval. Returns an empty handle if the cache doesn't contain a |
// script for the given source string. |
static Handle<JSFunction> LookupEval(Handle<String> source, |
+ Handle<Context> context, |
Entry entry); |
// Returns the regexp data associated with the given regexp if it |
@@ -78,6 +79,14 @@ |
Entry entry, |
Handle<JSFunction> boilerplate); |
+ // Associate the (source, context->closure()->shared(), kind) |
+ // tripple with the boilerplate. This may overwrite an existing |
Kasper Lund
2009/02/24 11:21:08
tripple -> triple
|
+ // mapping. |
+ static void PutEvalFunction(Handle<String> source, |
+ Handle<Context> context, |
+ Entry entry, |
+ Handle<JSFunction> boilerplate); |
+ |
// Clear the cache - also used to initialize the cache at startup. |
static void Clear(); |
@@ -55,10 +55,11 @@ |
int line_offset, |
int column_offset); |
- // Finds the function boilerplate for a source string for |
- // eval. Returns an empty handle if the cache doesn't contain a |
- // script for the given source string. |
+ // Finds the function boilerplate for a source string for eval in a |
+ // given context. Returns an empty handle if the cache doesn't |
+ // contain a script for the given source string. |
static Handle<JSFunction> LookupEval(Handle<String> source, |